@@ -382,7 +382,7 @@ def main():
 
     args = parser.parse_args()
     logger.debug("argparse namespace: {}", args)
-    print(args)
+    #print(args)
 
     for command in args.__dict__:
         cv = args.__dict__[command]
